:orphan:

.. Links to external resources

.. Hiveeyes
.. _Hiveeyes project: https://hiveeyes.org/
.. _Hiveeyes system: https://hiveeyes.org/docs/system/
.. _Hiveeyes platform: https://swarm.hiveeyes.org/
.. _Bencode: https://en.wikipedia.org/wiki/Bencode

.. computourist
.. _computourist: https://github.com/computourist
.. _RFM69 based sensors and MQTT gateway: https://github.com/computourist/RFM69-MQTT-client

.. LowPowerLab
.. _LowPowerLab: https://lowpowerlab.com/
.. _Felix Rusu: https://github.com/LowPowerLab
.. _RFM69: https://github.com/LowPowerLab/RFM69
.. _RFM69 library: https://github.com/LowPowerLab/RFM69
.. _RFM69.h#L35: https://github.com/LowPowerLab/RFM69/blob/master/RFM69.h#L35

.. JeeLabs
.. _JeeLabs: http://jeelabs.org/
.. _Jean-Claude Wippler: https://github.com/jcw
.. _JeeLink v3c: http://jeelabs.net/projects/hardware/wiki/JeeLink#JeeLink-v3c
.. _JeeLink v3c shop: http://www.digitalsmarties.net/products/jeelink
.. _EmBencode: https://github.com/jcw/embencode
.. _EmBencode encoding bug: https://github.com/jcw/embencode/pull/2
.. _EmBencode documentation: http://jeelabs.net/pub/docs/embencode/

.. More hardware
.. _LinkIt Smart 7688 Duo: https://community.hiveeyes.org/t/linkit-smart-7688-duo/105

.. Foundation technologies, protocols and subsystem services
.. _Bencode: https://en.wikipedia.org/wiki/Bencode
.. _Bencoding: https://wiki.theory.org/BitTorrentSpecification#Bencoding
.. _MQTT: http://mqtt.org/
.. _UUID4: https://en.wikipedia.org/wiki/Universally_unique_identifier#Version_4_.28random.29
.. _Arduino: https://www.arduino.cc/

.. MQTT
.. _Andy Piper: http://andypiper.co.uk
.. _Didier Donsez: http://lig-membres.imag.fr/donsez/
.. _A Python script to push serial data to MQTT: http://air.imag.fr/index.php/Mosquitto#Publication_en_Python

.. Other systems
.. _CuPID Controls: https://www.interfaceinnovations.org/cupidcontrols.html
.. _Interface Innovations: https://www.interfaceinnovations.org/


.. NEW
.. _Martin Harizanov: https://harizanov.com/
.. _RFM69 to MQTT gateway using ESP8266: https://harizanov.com/2015/11/rfm69-to-mqtt-gateway-using-esp8266/

.. _Johan Kanflo: http://johan.kanflo.com/
.. _Serializing data from IoT nodes: http://johan.kanflo.com/serializing-data-from-iot-nodes/

.. _SMILE: https://en.wikipedia.org/wiki/Smile_%28data_interchange_format%29
.. _UBJSON: http://ubjson.org/
.. _UBJSON at Wikipedia: https://en.wikipedia.org/wiki/UBJSON

.. _OpenWrt: https://openwrt.org/
.. _NodeMCU: http://nodemcu.com/index_en.html
